@@ -185,7 +185,8 @@ class Session(Workspace):
         :type query: str, neo4j.Query
         :param parameters: dictionary of parameters
         :type parameters: dict
-        :param kwparameters: additional keyword parameters
+        :param kwparameters: additional keyword parameters.
+            These take precedence over parameters passed as ``parameters``.
         :returns: a new :class:`neo4j.Result` object
         :rtype: :class:`neo4j.Result`
         """
@@ -212,17 +213,18 @@ class Session(Workspace):
             cx, hydrant, self._config.fetch_size, self._result_closed,
             self._result_error
         )
+        parameters = dict(parameters or {}, **kwparameters)
         self._autoResult._run(
             query, parameters, self._config.database,
             self._config.impersonated_user, self._config.default_access_mode,
-            self._bookmarks, **kwparameters
+            self._bookmarks
         )
 
         return self._autoResult
 
     def last_bookmark(self):
         """Return the bookmark received following the last completed transaction.
-        Note: For auto-transaction (Session.run) this will trigger an consume for the current result.
+        Note: For auto-transaction (Session.run) this will trigger a consume for the current result.
 
         :returns: :class:`neo4j.Bookmark` object
         """
@@ -477,6 +479,8 @@ def unit_of_work(metadata=None, timeout=None):
         Transactions that execute longer than the configured timeout will be terminated by the database.
         This functionality allows to limit query/transaction execution time.
         Specified timeout overrides the default timeout configured in the database using ``dbms.transaction.timeout`` setting.
+        Values higher than ``dbms.transaction.timeout`` will be ignored and
+        will fall back to default (unless using Neo4j < 4.2).
         Value should not represent a duration of zero or negative duration.
     :type timeout: float or :const:`None`
     """
